@@ -77,10 +77,13 @@ class DataClient(object):
 
         code_list, msg_list = [], []
         for index, t in enumerate(teachers):
+            teacher_sso_data = t.sso_data
             if t.uid:
-                code, rlt = update_teacher_req(t.uid, t.sso_data, school_id=t.school)
+                teacher_sso_data.pop("password")
+                code, rlt = update_teacher_req(t.uid, teacher_sso_data, school_id=t.school)
             elif t.number in teacher_map:
-                code, rlt = update_teacher_req(teacher_map[t.number], t.sso_data, school_id=t.school)
+                teacher_sso_data.pop("password")
+                code, rlt = update_teacher_req(teacher_map[t.number], teacher_sso_data, school_id=t.school)
             else:
                 code, rlt = create_teacher_req(t.sso_data, school_id=t.school)
             if code:
