@@ -42,9 +42,9 @@ class SectionSync(BaseSync):
         if not self.section_map:
             logger.info("没有班级信息")
             return
-        # if self.create:
-        #     for code, section in self.section_map.items():
-        #         code, data = self.client.create_section(sections=section)
-        #         if code:
-        #             logger.error("Code: {}, Msg: {}".format(code, data))
+        if self.create:
+            for code, section in self.section_map.items():
+                code, data = self.client.create_section(sections=section)
+                if code:
+                    logger.error("Code: {}, Msg: {}".format(code, data))
         self.close_db()
