@@ -15,6 +15,7 @@ class StudentSync(BaseSync):
         self.student_map = {}
         self.create = True
         self.student_section_map = {}
+        self.current_number_list = []
 
     def get_section_map(self):
         code, sections = self.client.get_section_list(school_id=self.school_id)
@@ -44,13 +45,21 @@ class StudentSync(BaseSync):
                                   classof=2018, graduateat=2021, school=self.school_id)
                 self.student_map[external_id] = number
                 self.student_list.append(student)
+                self.current_number_list.append(number)
+
+    def delete_old_student(self):
+        student_number_map = self.client.get_student_number_map(self.school_id)
+        for db_student_number, db_student_id in student_number_map.items():
+            if db_student_number not in self.current_number_list:
+                delete_code, delete_data = self.client.delete_student({"student_id": db_student_id}, self.school_id)
+                print(delete_code, delete_data)
 
     def sync(self):
         self.extract_student()
         if not self.student_map:
             logger.info("没有学生信息")
             return
-        # if self.create:
-        #     code, data = self.client.create_student(self.student_list)
-        #     logger.info("Code: {}, Msg: {}".format(code, data))
+        if self.create:
+            code, data = self.client.create_student(self.student_list)
+            logger.info("Code: {}, Msg: {}".format(code, data))
         self.close_db()
