@@ -8,8 +8,12 @@ NICE_HOST = os.environ.get("NICE_HOST", "xgk.lanzhou.edu.cn/schoolscheduleserv/i
 # NICE_HOST = os.environ.get("NICE_HOST", "connect.nicezhuanye.com/schoolscheduleserv/integration")
 
 NIRVANA_PROTOCOL = os.environ.get("NIRVANA_PROTOCOL", "http")
-NIRVANA_HOST = os.environ.get("NIRVANA_HOST", "10.88.190.210")
+NIRVANA_HOST = os.environ.get("NIRVANA_HOST", "10.100.1.23")
 NIRVANA_PORT = int(os.environ.get("NIRVANA_PORT", 14001))
-NIRVANA_SCHOOL = os.environ.get("NIRVANA_SCHOOL", "35482fb5-6215-4187-a025-0562819eaef2")
 NIRVANA_TOKEN = os.environ.get("NIRVANA_TOKEN", "skeleton gjtxsjtyjsxqsl Z2p0eHNqdHlqc3hxc2w=")
 
+EDTECH_SERVER_URL = os.environ.get("EDTECH_SERVER_URL", "http://10.100.1.23:12363")
+EDTECH_SERVER_TOKEN = os.environ.get("EDTECH_SERVER_TOKEN", "Token 6c5a192e3e161342489971b10d36dee5250e64dd")
+CLASS_CARD_SERVER_URL = os.environ.get("CLASS_CARD_SERVER_URL", "http://10.100.1.23:14001")
+CLASS_CARD_SERVER_TOKEN = os.environ.get("CLASS_CARD_SERVER_TOKEN", "Skeleton gjtxsjtyjsxqsl Z2p0eHNqdHlqc3hxc2w=")
+
