@@ -95,8 +95,29 @@ class NiceRequester(Requester):
         return res
 
 
-a1 = [35,35,37,36,33,34,63,67,66,65,64,67,64,67,67,67,39,39,36,37,36,38,44,34,39,43,40,49,79,78,80,75,74,77]
-sum(a1)
+classroom_class = {}
 nice_requester = NiceRequester("3550", host="xgk.lanzhou.edu.cn/schoolscheduleserv/integration", protocol="https")
-res = nice_requester.get_student_list()
-print(res)
+class_number_map = {}
+res_data = nice_requester.get_class_list()
+for index, rd in enumerate(res_data["classes"]):
+    try:
+        principal_number = rd['classTeacher']['teacherEID']
+    except (Exception,):
+        principal_number = None
+    class_number_map[rd['classFullName']] = rd['qualifiedClassID']
+    if rd['locationID']:
+        if rd['locationID'] not in classroom_class:
+            classroom_class[rd['locationID']] = []
+        classroom_class[rd['locationID']].append(rd['classFullName'])
+section_classroom = {}
+room_data = nice_requester.get_classroom_list()
+for rd in room_data["locations"]:
+    if rd['locationID'] in classroom_class:
+        section_classroom[classroom_class[rd['locationID']][0]] = rd['locationName']
+course_class_list = set()
+response = nice_requester.get_table(current=True)
+for course_info in response['schedule']:
+    is_walking = course_info['classType'] in ["教学班", "选修班"]
+    if not is_walking:
+        course_class_list.add(course_info['qualifiedClassID'])
+print(res_data)
