@@ -34,7 +34,7 @@ class StudentSync(BaseSync3):
             current_number_list.append(rd['studentEID'])
         for db_student_number, db_student_id in student_number_map.items():
             if db_student_number not in current_number_list:
-                delete_code, delete_data = self.client.delete_student({"number": db_student_number}, self.school_id)
+                delete_code, delete_data = self.client.delete_student({"student_id": db_student_id}, self.school_id)
                 print(delete_code, delete_data)
-        # code, data = self.client.create_student(student_list)
-        # logger.info("Code: {}, Msg: {}".format(code, data))
+        code, data = self.client.create_student(student_list)
+        logger.info("Code: {}, Msg: {}".format(code, data))
