@@ -7,6 +7,7 @@ from sync.course2 import CourseSyncV2
 from sync.course import CourseSyncV1
 from sync.subject import SubjectSync
 from sync.school import SchoolSync
+from sync.clear import ClearSyncV2
 from utils.loggerutils import logging
 
 logger = logging.getLogger(__name__)
@@ -62,6 +63,8 @@ def start_sync_v2():
             continue
         is_walking = WALKING_MAP.get(number, True)
         school_info = {"school_name": name, "school_number": number}
+        clear_sync = ClearSyncV2(**school_info)
+        clear_sync.start()
         teacher_sync = TeacherSync(**school_info)
         teacher_sync.start()
         class_sync = ClassSync(**school_info)
@@ -75,6 +78,7 @@ def start_sync_v2():
         subject_sync = SubjectSync(**school_info)
         subject_sync.start()
         course_sync = CourseSyncV2(**school_info)
+        course_sync.subject_num_map = subject_sync.subject_num_map
         course_sync.is_walking = is_walking
         course_sync.classroom_map = classroom_sync.id_num_map
         course_sync.start()
