@@ -26,6 +26,7 @@ def get_school_id():
 
 
 def transact_section_data():
+    current_number_list = []
     logger.info("start section data sync at {}".format(datetime.now()))
     # 学校数据
     code, school_id = get_school_id()
@@ -46,6 +47,7 @@ def transact_section_data():
             current_rows = section_res["data"]["Rows"]
             for d in current_rows:
                 section = section_convert(data=d, school=school_id)
+                current_number_list.append(section.number)
                 code, data = client.create_section(sections=section)
                 if code:
                     logger.error("Code: {}, Msg: {}".format(code, data))
@@ -59,13 +61,16 @@ def transact_section_data():
                                     "BH": "yjsection{}".format(current_year),
                                     "NJ": str(current_year)}
         current_yjs_section = section_convert(data=current_yjs_section_data, school=school_id)
+        current_number_list.append(current_yjs_section.number)
         code, data = client.create_section(sections=current_yjs_section)
         if code:
             logger.error("Code: {}, Msg: {}".format(code, data))
     logger.info("end section data sync at {}".format(datetime.now()))
+    return current_number_list
 
 
 def transact_student_data():
+    current_number_list = []
     logger.info("start student data sync at {}".format(datetime.now()))
     # 1. 学校数据
     code, school_id = get_school_id()
@@ -110,6 +115,7 @@ def transact_student_data():
                 student = bk_student_convert(data=d, ecard=ecard, school=school_id, section=section_id)
                 if student.number in number_map:
                     student.uid = number_map[student.number]
+                current_number_list.append(student.number)
                 code, data = client.create_student(students=student)
                 if code:
                     logger.error("Code: {}, Msg: {}".format(code, data))
@@ -134,6 +140,7 @@ def transact_student_data():
                 student = yj_student_convert(data=d, ecard=ecard, school=school_id, section=section_id)
                 if student.number in number_map:
                     student.uid = number_map[student.number]
+                current_number_list.append(student.number)
                 code, data = client.create_student(students=student)
                 if code:
                     logger.error("Code: {}, Msg: {}".format(code, data))
@@ -143,9 +150,11 @@ def transact_student_data():
                 break
             page_index += 1
     logger.info("end student data sync at {}".format(datetime.now()))
+    return current_number_list
 
 
 def transact_teacher_data():
+    current_number_list = []
     logger.info("start teacher data sync at {}".format(datetime.now()))
     # 1. 学校数据
     code, school_id = get_school_id()
@@ -178,6 +187,7 @@ def transact_teacher_data():
             if teacher.number in number_map:
                 teacher.uid = number_map[teacher.number]
                 logger.info("find number {}: {}".format(teacher.number, teacher.uid))
+            current_number_list.append(teacher.number)
             code, data = client.create_teacher(teacher)
             if code:
                 logger.error("Code: {}, Msg: {}".format(code, data))
@@ -187,14 +197,15 @@ def transact_teacher_data():
             break
         page_index += 1
     logger.info("end teacher data sync at {}".format(datetime.now()))
+    return current_number_list
 
 
 def start_data_sync():
     start_time = time.time()
     logger.info("start data sync at {}".format(datetime.now()))
-    # transact_section_data()
-    # transact_student_data()
-    transact_teacher_data()
+    current_section_num = transact_section_data()
+    current_student_num = transact_student_data()
+    current_teacher_num = transact_teacher_data()
     logger.info("end data sync at {}".format(datetime.now()))
     logger.info("data sync used: {}s".format(round(time.time() - start_time, 4)))
 
