@@ -76,6 +76,11 @@ class SDTURequester(Requester):
         return res
 
     def get_yjs_semester(self, **data):
-        route = "/getREST_YJSXL_83cc62e7ab9243f39a07cb0fcc69fd75"
+        route = "/getREST_YJSXQXX_5cec366826024c608353c11ada2d0012"
+        res = self._post_method(route, data=data)
+        return res
+
+    def get_bks_subject_name(self, **data):
+        route = "/REST/JWKCDMB/WC"
         res = self._post_method(route, data=data)
         return res
