@@ -208,7 +208,7 @@ class CourseTableSync(BaseSync):
                                                                       building=building, floor=floor,
                                                                       category=RoomType.TYPE_PUBLIC,
                                                                       extra_info={'campus': campus})
-                course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
+                course = Course(number=course_number, name=get_md5_hash(course_name), teacher_number=teacher_number,
                                 classroom_number=classroom_num, subject_number=subject_number,
                                 begin_week=time_result['begin_week'], end_week=time_result['end_week'],
                                 required_student=False, is_present=True)
@@ -272,7 +272,7 @@ class CourseTableSync(BaseSync):
                                                                       extra_info={'campus': campus})
                     if subject_number not in self.subject_map:
                         self.add_subject(subject_name, subject_number, subject_info['ori_num'])
-                    course = Course(number=course_number, name=course_name[:63], teacher_number=teacher_number,
+                    course = Course(number=course_number, name=get_md5_hash(course_name), teacher_number=teacher_number,
                                     classroom_number=classroom_num, subject_number=subject_number, is_present=True,
                                     begin_week=begin_week, end_week=end_week, required_student=False)
                     self.course_map[course_name] = course
@@ -442,7 +442,7 @@ class CourseTableSync(BaseSync):
                     course = course_map[course_name]
                 else:
                     course_number = get_md5_hash(course_name)
-                    course_data = dict(number=course_number, name=course_name[:63], classroom_number=classroom_num,
+                    course_data = dict(number=course_number, name=get_md5_hash(course_name), classroom_number=classroom_num,
                                        subject_number=subject_number, is_present=True, begin_week=begin_week,
                                        end_week=end_week, required_student=False)
                     if teacher_number:
