@@ -1,5 +1,6 @@
 import os
 import cx_Oracle
+import time
 import datetime
 from sync.base import BaseSync
 from config import AVATAR_ORACLE_SERVER, AVATAR_PATH
@@ -71,23 +72,35 @@ class AvatarSync(BaseSync):
                       "FROM (SELECT x.*, rownum r FROM T_YKT_PHOTO x " \
                       "ORDER BY XGH) " \
                       "k WHERE k.r BETWEEN {} and {}".format(si, ei)
+            sql_s = time.time()
             self.cur.execute(sql)
             rows = self.cur.fetchall()
+            logger.info("sql photo cost: {}s".format(time.time() - sql_s))
             for row in rows:
                 number, name, avatar = row[0], row[1], row[2].read()
                 if not (number and name and avatar):
                     continue
                 file_name = "{}-{}.jpg".format(name, number)
                 file_path = os.path.join(AVATAR_PATH, file_name)
+                write_s = time.time()
                 self.write_file(avatar, file_path)
+                logger.info("write photo cost: {}s".format(time.time() - write_s))
                 if number in student_number_map:
                     user_id = student_number_map[number]
+                    upload_s = time.time()
                     self.client.upload_user_avatar(self.school_id, file_path, user_id)
+                    logger.info("upload avatar cost: {}s".format(time.time() - upload_s))
+                    upload_s = time.time()
                     self.client.upload_user_face(self.school_id, file_path, student_id=user_id)
+                    logger.info("upload face cost: {}s".format(time.time() - upload_s))
                 if number in teacher_number_map:
                     user_id = teacher_number_map[number]
+                    upload_s = time.time()
                     self.client.upload_user_avatar(self.school_id, file_path, user_id)
+                    logger.info("upload avatar cost: {}s".format(time.time() - upload_s))
+                    upload_s = time.time()
                     self.client.upload_user_face(self.school_id, file_path, teacher_id=user_id)
+                    logger.info("upload face cost: {}s".format(time.time() - upload_s))
                 os.remove(file_path)
                 logger.info("already upload {}/{} avatar".format(row_index, total))
                 row_index += 1
