@@ -18,6 +18,7 @@ class ClassroomSync(BaseSync):
         self.bks_classroom_map = {}
         self.classroom_name_list = []
         self.db_name_num = {}
+        self.current_classroom_num = []
 
     def analyse_building(self, classroom_name):
         building, floor = None, None
@@ -67,6 +68,7 @@ class ClassroomSync(BaseSync):
                                                                   extra_info={'campus': campus})
                     self.bks_classroom_map[name] = classroom_num
                     self.classroom_name_list.append(name)
+                    self.current_classroom_num.append(classroom_num)
             if page_index * SDTU_PAGE_SIZE >= total_count:
                 break
             page_index += 1
@@ -92,6 +94,7 @@ class ClassroomSync(BaseSync):
                                                                   extra_info={'campus': campus})
                     self.yjs_classroom_map[yjs_number] = classroom_num
                     self.classroom_name_list.append(name)
+                    self.current_classroom_num.append(classroom_num)
             if page_index * SDTU_PAGE_SIZE >= total_count:
                 break
             page_index += 1
