@@ -7,7 +7,7 @@ from utils.code import get_md5_hash
 from classcard_dataclient.models.course import CourseTableManager, Course
 from classcard_dataclient.models.subject import Subject
 from utils.loggerutils import logging
-from utils.dateutils import date2str
+from utils.dateutils import date2str, str2datetime
 from requester.sdtu import SDTURequester
 from config import SDTU_PAGE_SIZE
 
@@ -39,6 +39,20 @@ class CourseTableSync(BaseSync):
         self.need_relate_student = True
         self.yjs_classroom_map = {}
         self.bks_classroom_map = {}
+        self.bks_subject_name = {}
+
+    def get_bks_subject_name(self):
+        page_index = 1
+        while True:
+            classroom_res = self.sdtu_requester.get_bks_subject_name(page=page_index, pagesize=SDTU_PAGE_SIZE)
+            total_count = classroom_res["total"]
+            current_rows = classroom_res["data"]["Rows"]
+            for d in current_rows:
+                subject_name, subject_num = d["KCZWMC"], d["KCDM"]
+                self.bks_subject_name[subject_num] = subject_name
+            if page_index * SDTU_PAGE_SIZE >= total_count:
+                break
+            page_index += 1
 
     def get_bks_semester_info(self):
         semester_res = self.sdtu_requester.get_bks_semester(page=1, pagesize=SDTU_PAGE_SIZE)
@@ -48,14 +62,19 @@ class CourseTableSync(BaseSync):
             current_semester = data_list[0]
             self.table_begin_date, self.table_end_date = current_semester["KSRQ"], current_semester["JSRQ"]
             self.xn, self.bks_xq = current_semester["XN"], current_semester["XQDM"]
+        logger.info("self.xn, self.bks_xq: {}, {}".format(self.xn, self.bks_xq))
 
     def get_yjs_semester_info(self):
+        now_time = datetime.datetime.now()
         semester_res = self.sdtu_requester.get_yjs_semester(page=1, pagesize=SDTU_PAGE_SIZE)
         data_list = semester_res["data"]["Rows"]
-        data_list = sorted(data_list, key=lambda d: d["BEGINDATE"], reverse=True)
-        if data_list:
-            current_semester = data_list[0]
-            self.yjs_xq = current_semester["TERMCODE"]
+        data_list = sorted(data_list, key=lambda d: d["KSSJ"], reverse=True)
+        for data_item in data_list:
+            start_time, end_time = str2datetime(data_item["KSSJ"][:19]), str2datetime(data_item["JSSJ"][:19])
+            if start_time <= now_time <= end_time:
+                self.yjs_xq = data_item["XQDM"]
+                break
+        logger.info("self.yjs_xq: {}".format(self.yjs_xq))
 
     def process_subject_info(self, subject_name):
         if not subject_name:
@@ -143,9 +162,13 @@ class CourseTableSync(BaseSync):
                                                                   params={"XQ": str(self.yjs_xq)})
             total_count = course_res["total"]
             current_rows = course_res["data"]["Rows"]
+            if not current_rows:
+                logger.info("get_yjs_course current_rows is 0!!!!!!")
+                time.sleep(3)
             for row in current_rows:
                 subject_name = row["KCMC"]
                 if not subject_name:
+                    logger.info("get_yjs_course not subject_name")
                     continue
                 subject_info = self.process_subject_info(subject_name)
                 subject_name, subject_number = subject_info['name'], subject_info['number']
@@ -154,13 +177,18 @@ class CourseTableSync(BaseSync):
                 classroom_num = self.yjs_classroom_map.get(classroom_yjs_num)
                 time_info = row["SKSJMS"]
                 if not (time_info and classroom_num):
+                    logger.info("get_yjs_course not (time_info and classroom_num)")
                     continue
                 time_result = self.analyse_sksj(time_info)
                 if not time_result:
+                    logger.info("get_yjs_course not time_result")
                     continue
                 try:
                     course_name = classroom_num + subject_number + teacher_number
                 except (Exception,):
+                    logger.info("get_yjs_course not course_name")
+                    import traceback
+                    logger.info(traceback.format_exc())
                     continue
                 if course_name in course_map:
                     course = course_map[course_name]
@@ -208,9 +236,14 @@ class CourseTableSync(BaseSync):
                                                                               "XN": str(self.xn)})
             total_count = course_res["total"]
             current_rows = course_res["data"]["Rows"]
+            if not current_rows:
+                logger.info("get_yjs_course current_rows is 0!!!!!!")
+                time.sleep(3)
             for row in current_rows:
-                subject_name = row["KCMC"]
+                subject_name, bks_subject_num = row["KCMC"], row["KCDM"]
+                subject_name = self.bks_subject_name.get(bks_subject_num)
                 if not subject_name:
+                    logger.info("get_bk_course not subject_name")
                     continue
                 subject_info = self.process_subject_info(subject_name)
                 subject_name, subject_number = subject_info['name'], subject_info['number']
@@ -221,31 +254,49 @@ class CourseTableSync(BaseSync):
                 week, num = row["XQJ"], row["JC"]
                 single = single_map.get(row["DSZ"], 0)
                 if not (week_range and classroom_name and week and num and teacher_number):
+                    logger.info("get_bk_course not (week_range and classroom_name and week and num and teacher_number)")
                     continue
                 classroom_num = self.bks_classroom_map.get(classroom_name, None) or get_md5_hash(classroom_name)
                 week_range = week_range.replace("周", "")
-                begin_week, end_week = int(week_range.split("-")[0]), int(week_range.split("-")[-1])
-                try:
-                    space_name = classroom_num + week_range + num + week + str(single)
-                    course_name = classroom_name + subject_number + teacher_number + str(class_number)
-                except (Exception,) as e:
-                    continue
-                if course_name in self.course_map:
-                    course = self.course_map[course_name]
+                if "(单)" in week_range or "(双)" in week_range or "," in week_range:
+                    week_range_list = week_range.split(",")
                 else:
-                    course_number = get_md5_hash(course_name)
-                    course = Course(number=course_number, name=course_number, teacher_number=teacher_number,
-                                    classroom_number=classroom_num, subject_number=subject_number, is_present=True,
-                                    begin_week=begin_week, end_week=end_week, required_student=False)
-                    self.course_map[course_name] = course
+                    week_range_list = [week_range]
+                for week_range_item in week_range_list:
+                    if "(单)" in week_range_item or "(双)" in week_range_item:
+                        single = single_map.get(week_range_item[-2], 0)
+                        week_range_item = week_range_item[:-3]
+                    try:
+                        begin_week, end_week = int(week_range_item.split("-")[0]), int(week_range_item.split("-")[-1])
+                    except (Exception,):
+                        import traceback
+                        logger.info(week_range)
+                        logger.info(traceback.format_exc())
+                        time.sleep(2)
+                        continue
+                    try:
+                        space_name = classroom_num + str(begin_week) + '-' + str(end_week) + num + week + str(single)
+                        course_name = classroom_name + subject_number + teacher_number + str(class_number)
+                    except (Exception,) as e:
+                        import traceback
+                        logger.info(traceback.format_exc())
+                        continue
+                    if course_name in self.course_map:
+                        course = self.course_map[course_name]
+                    else:
+                        course_number = get_md5_hash(course_name)
+                        course = Course(number=course_number, name=course_number, teacher_number=teacher_number,
+                                        classroom_number=classroom_num, subject_number=subject_number, is_present=True,
+                                        begin_week=begin_week, end_week=end_week, required_student=False)
+                        self.course_map[course_name] = course
 
-                positions = self.analyse_position(num, week)
-                for position in positions:
-                    course.add_position(position[0], position[1], single)
-                if space_name not in self.space_container:
-                    self.space_container[space_name] = []
-                if course_name not in self.space_container[space_name]:
-                    self.space_container[space_name].append(course)
+                    positions = self.analyse_position(num, week)
+                    for position in positions:
+                        course.add_position(position[0], position[1], single)
+                    if space_name not in self.space_container:
+                        self.space_container[space_name] = []
+                    if course_name not in self.space_container[space_name]:
+                        self.space_container[space_name].append(course)
             if page_index * SDTU_PAGE_SIZE >= total_count:
                 break
             page_index += 1
@@ -268,9 +319,18 @@ class CourseTableSync(BaseSync):
                 student_number = row["XH"]
                 if not (week_range and classroom_name and subject_name and week and num):
                     continue
+                week_range = week_range.replace("周", "")
+                try:
+                    begin_week, end_week = int(week_range.split("-")[0]), int(week_range.split("-")[-1])
+                except (Exception,):
+                    import traceback
+                    logger.info(week_range)
+                    logger.info(traceback.format_exc())
+                    time.sleep(2)
+                    continue
                 classroom_num = self.bks_classroom_map.get(classroom_name, None) or get_md5_hash(classroom_name)
                 try:
-                    space_name = classroom_num + week_range + num + week + str(single)
+                    space_name = classroom_num + str(begin_week) + '-' + str(end_week) + num + week + str(single)
                 except (Exception,):
                     continue
                 course = self.space_map.get(space_name, None)
@@ -343,6 +403,7 @@ class CourseTableSync(BaseSync):
     def sync(self):
         self.record(">>>Start course sync")
         t1 = time.time()
+        self.get_bks_subject_name()
         self.get_bk_course()
         self.combine_course()
         self.record(">>>Total have {} courses".format(len(self.course_map)))
@@ -378,4 +439,4 @@ class CourseTableSync(BaseSync):
         dir_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
         file_path = os.path.join(dir_path, "course_info.txt")
         with open(file_path, "a+") as f:
-            f.write("{} >>> {} \n".format(now, info))
\ No newline at end of file
+            f.write("{} >>> {} \n".format(now, info))
